==> qtjambi-qml-debuginfo-macos-6.6.0.jar: sources/QtJambiQml/QQmlInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmlinfo.h>
#include <QtCore/QVariant>
#include <QtQuick/qquickwindow.h>
#include <QtGui/qwindow.h>
#include <QtCore/qdebug.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlInfo")
    QQmlInfo *_ptr = reinterpret_cast<QQmlInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QQmlInfo(QQmlInfo)
void __qt_construct_QQmlInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlInfo(QQmlInfo)")
    jobject arg__1 = __java_arguments[0].l;
    const QQmlInfo& __qt_arg__1 = qtjambi_cast<const QQmlInfo& >(__jni_env, arg__1);
    QQmlInfo *__qt_this = new(__qtjambi_ptr) QQmlInfo(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QQmlInfo
void __qt_destruct_QQmlInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlInfo")
    reinterpret_cast<QQmlInfo*>(ptr)->~QQmlInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlInfo::QQmlInfo(QQmlInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlInfo_initialize_1native__Lio_qt_qml_QQmlInfo_2Lio_qt_qml_QQmlInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlInfo::QQmlInfo(QQmlInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlInfo_0, sizeof(QQmlInfo), typeid(QQmlInfo), false, &deleter_QQmlInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlInfo::operator<<(QQmlInfo,const QWindow*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlInfo_append_1native_1const_1QWindow_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID window1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QQmlInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQmlInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlInfo::operator<<(QQmlInfo,const QWindow*)", __qt_this)
        const QWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QWindow>(window1);
        QQmlInfo __qt_return_value = (*__qt_this) << __qt_window1;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void custom_default_constructor_QQmlInfo(const QtPrivate::QMetaTypeInterface *metaTypeInterface, void* placement)
{
    Q_UNUSED(metaTypeInterface)
    Q_UNUSED(placement)
    new(placement) QQmlInfo(qmlDebug(nullptr));
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQmlInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQmlInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQmlInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQmlInfo>("QQmlInfo", "io/qt/qml/QQmlInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQmlInfo, {
        ConstructorInfo(&__qt_construct_QQmlInfo_0, "Lio/qt/qml/QQmlInfo;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlInfo);
    registerMetaType<QQmlInfo>("QQmlInfo", &custom_default_constructor_QQmlInfo, QtJambiPrivate::QMetaTypeInterfaceFunctions<QQmlInfo>::copyCtr, QtJambiPrivate::QMetaTypeInterfaceFunctions<QQmlInfo>::moveCtr);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QIODeviceBase), int(reinterpret_cast<quintptr>(static_cast<QIODeviceBase *>(reinterpret_cast<QQmlInfo *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.8.1.jar: sources/QtJambiQml/QQmlInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmlinfo.h>
#include <QtCore/QVariant>
#include <QtCore/qdebug.h>
#include <QtGui/qwindow.h>
#include <QtQuick/qquickwindow.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlInfo")
    QQmlInfo *_ptr = reinterpret_cast<QQmlInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QQmlInfo(QQmlInfo)
void __qt_construct_QQmlInfo_cref_QQmlInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlInfo(QQmlInfo)")
    jobject arg__1 = __java_arguments[0].l;
    const QQmlInfo& __qt_arg__1 = qtjambi_cast<const QQmlInfo&>(__jni_env, arg__1);
    QQmlInfo *__qt_this = new(__qtjambi_ptr) QQmlInfo(__qt_arg__1);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QQmlInfo::QQmlInfo(QQmlInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlInfo_initialize_1native__Lio_qt_qml_QQmlInfo_2Lio_qt_qml_QQmlInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlInfo::QQmlInfo(QQmlInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlInfo_cref_QQmlInfo, sizeof(QQmlInfo), typeid(QQmlInfo), 0, false, &deleter_QQmlInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlInfo
void __qt_destruct_QQmlInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlInfo")
    reinterpret_cast<QQmlInfo*>(ptr)->~QQmlInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlInfo::operator<<(QQmlInfo,const QWindow*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlInfo_append_1native_1const_1QWindow_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID window1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QQmlInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQmlInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlInfo::operator<<(QQmlInfo,const QWindow*)", __this_nativeId)
        const QWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QWindow>(window1);
        QQmlInfo __qt_return_value = (*__qt_this) << __qt_window1;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void custom_default_constructor_QQmlInfo(const QtPrivate::QMetaTypeInterface *metaTypeInterface, void* placement)
{
    Q_UNUSED(metaTypeInterface)
    Q_UNUSED(placement)
    new(placement) QQmlInfo(qmlDebug(nullptr));
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQmlInfo *__qt_this = QtJambiAPI::objectFromNativeId<QQmlInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQmlInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQmlInfo>("QQmlInfo", "io/qt/qml/QQmlInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlInfo, {
        ConstructorInfo{&__qt_construct_QQmlInfo_cref_QQmlInfo, "Lio/qt/qml/QQmlInfo;"}
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlInfo);
    registerMetaType<QQmlInfo>("QQmlInfo", &custom_default_constructor_QQmlInfo, QtJambiPrivate::QMetaTypeInterfaceFunctions<QQmlInfo>::copyCtr, QtJambiPrivate::QMetaTypeInterfaceFunctions<QQmlInfo>::moveCtr);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QIODeviceBase), int(reinterpret_cast<quintptr>(static_cast<QIODeviceBase *>(reinterpret_cast<QQmlInfo *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}
